======================= =================== ====================================
Dependency              Minimum Version     Purpose
======================= =================== ====================================
numpy                   1.17.3              build, install
scipy                   1.5.0               build, install
joblib                  1.1.1               install
threadpoolctl           2.0.0               install
cython                  0.29.33             build
matplotlib              3.1.3               benchmark, docs, examples, tests
scikit-image            0.16.2              docs, examples, tests
pandas                  1.0.5               benchmark, docs, examples, tests
seaborn                 0.9.0               docs, examples
memory_profiler         0.57.0              benchmark, docs
pytest                  7.1.2               tests
pytest-cov              2.9.0               tests
ruff                    0.0.272             tests
black                   23.3.0              tests
mypy                    1.3                 tests
pyamg                   4.0.0               tests
sphinx                  6.0.0               docs
sphinx-copybutton       0.5.2               docs
sphinx-gallery          0.10.1              docs
numpydoc                1.2.0               docs, tests
Pillow                  7.1.2               docs
pooch                   1.6.0               docs, examples, tests
sphinx-prompt           1.3.0               docs
sphinxext-opengraph     0.4.2               docs
plotly                  5.14.0              docs, examples
conda-lock              2.0.0               maintenance
======================= =================== ====================================
